==> jc-1.4.0.tar.gz: java/util/Hashtable__241.h <==
// final class java.util.Hashtable$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class c5dacebc5c451662 java_util_Hashtable__241

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_java_util_Hashtable__241_H_
#define _JC_java_util_Hashtable__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_Hashtable__241$sub_refs	_jc_java_util_Hashtable__241$sub_refs;
typedef struct _jc_java_util_Hashtable__241$sub_nonrefs	_jc_java_util_Hashtable__241$sub_nonrefs;
typedef struct _jc_java_util_Hashtable__241$refs	_jc_java_util_Hashtable__241$refs;
typedef struct _jc_java_util_Hashtable__241$nonrefs	_jc_java_util_Hashtable__241$nonrefs;
typedef struct _jc_java_util_Hashtable__241$object	_jc_java_util_Hashtable__241$object;

typedef const struct _jc_java_util_Hashtable__241$vmethods	_jc_java_util_Hashtable__241$vmethods;
typedef const struct _jc_java_util_Hashtable__241$vtable	_jc_java_util_Hashtable__241$vtable;
typedef const struct _jc_java_util_Hashtable__241$vtype	_jc_java_util_Hashtable__241$vtype;

// Constructors
extern void _jc_java_util_Hashtable__241$method$_init$b0d87fb0297b3970(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_util_Hashtable$object *);

// Virtual methods
extern void _jc_java_util_Hashtable__241$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_java_util_Hashtable__241$object *);
extern jboolean _jc_java_util_Hashtable__241$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_java_util_Hashtable__241$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_Hashtable__241$object *);
extern jboolean _jc_java_util_Hashtable__241$method$remove$d21babbbb7fafe72(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_Hashtable__241$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_Hashtable__241$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Hashtable__241$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_java_util_Hashtable__241$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_util_Hashtable__241$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_util_Hashtable__241$method_info$remove$d21babbbb7fafe72;
extern _jc_method _jc_java_util_Hashtable__241$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_java_util_Hashtable__241$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_java_util_Hashtable__241$object *);
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_Hashtable__241$object *);
	jboolean	(*remove$d21babbbb7fafe72)(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_lang_Object$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_Hashtable__241$object *);
};

// Vtable
struct _jc_java_util_Hashtable__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_Hashtable__241$vmethods	java_util_Hashtable__241;
};

// Vtype
struct _jc_java_util_Hashtable__241$vtype {
	_jc_type			type;
	_jc_java_util_Hashtable__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Hashtable__241$sub_refs {
	struct _jc_java_util_Hashtable$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Hashtable__241$refs {
    _jc_java_util_Hashtable__241$sub_refs	java_util_Hashtable__241;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Hashtable__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Hashtable__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_Hashtable__241$sub_nonrefs	java_util_Hashtable__241;
};

// Object instance structure
struct _jc_java_util_Hashtable__241$object {
	_jc_java_util_Hashtable__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Hashtable__241$vtype	*vtype;
	_jc_java_util_Hashtable__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Hashtable__241$vtype _jc_java_util_Hashtable__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Hashtable__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Hashtable__241$class_object;

#endif	/* _JC_java_util_Hashtable__241_H_ */

==> jc-1.4.6.tar.gz: java/util/Hashtable__241.h <==
// final class java.util.Hashtable$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class c5dacebc5c451662 java_util_Hashtable__241

// header file dependencies
// @dep_header java_util_AbstractSet

#include "java/util/AbstractSet.h"

#ifndef _JC_java_util_Hashtable__241_H_
#define _JC_java_util_Hashtable__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_util_Hashtable__241$sub_refs	_jc_java_util_Hashtable__241$sub_refs;
typedef struct _jc_java_util_Hashtable__241$sub_nonrefs	_jc_java_util_Hashtable__241$sub_nonrefs;
typedef struct _jc_java_util_Hashtable__241$refs	_jc_java_util_Hashtable__241$refs;
typedef struct _jc_java_util_Hashtable__241$nonrefs	_jc_java_util_Hashtable__241$nonrefs;
typedef struct _jc_java_util_Hashtable__241$object	_jc_java_util_Hashtable__241$object;

typedef const struct _jc_java_util_Hashtable__241$vmethods	_jc_java_util_Hashtable__241$vmethods;
typedef const struct _jc_java_util_Hashtable__241$vtable	_jc_java_util_Hashtable__241$vtable;
typedef const struct _jc_java_util_Hashtable__241$vtype	_jc_java_util_Hashtable__241$vtype;

// Constructors
extern void _jc_java_util_Hashtable__241$method$_init$b0d87fb0297b3970(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_Hashtable__241$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_java_util_Hashtable__241$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_Hashtable__241$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Hashtable__241$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_Hashtable__241$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_Hashtable__241$method$remove$d21babbbb7fafe72(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Hashtable__241$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_util_Hashtable__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Hashtable__241$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_java_util_Hashtable__241$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_util_Hashtable__241$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_util_Hashtable__241$method_info$remove$d21babbbb7fafe72;
extern _jc_method _jc_java_util_Hashtable__241$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_java_util_Hashtable__241$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_java_util_Hashtable__241$object *) _JC_JCNI_ATTR;
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_Hashtable__241$object *) _JC_JCNI_ATTR;
	jboolean	(*remove$d21babbbb7fafe72)(_jc_env *, struct _jc_java_util_Hashtable__241$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_util_Hashtable__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Hashtable__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_Hashtable__241$vmethods	java_util_Hashtable__241;
};

// Vtype
struct _jc_java_util_Hashtable__241$vtype {
	_jc_type			type;
	_jc_java_util_Hashtable__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Hashtable__241$sub_refs {
	struct _jc_java_util_Hashtable$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Hashtable__241$refs {
    _jc_java_util_Hashtable__241$sub_refs	java_util_Hashtable__241;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Hashtable__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Hashtable__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_Hashtable__241$sub_nonrefs	java_util_Hashtable__241;
};

// Object instance structure
struct _jc_java_util_Hashtable__241$object {
	_jc_java_util_Hashtable__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Hashtable__241$vtype	*vtype;
	_jc_java_util_Hashtable__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Hashtable__241$vtype _jc_java_util_Hashtable__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Hashtable__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Hashtable__241$class_object;

#endif	/* _JC_java_util_Hashtable__241_H_ */
